@@ -1,7 +1,7 @@
 from argparse import ArgumentParser
 
-from push import args as push_args, push
-from rollback import args as rollback_args, rollback
+from cx_releaser.scripts.push import args as push_args, push
+from cx_releaser.scripts.rollback import args as rollback_args, rollback
 
 
 def main():
